@@ -6,7 +6,7 @@
 
 SEXP matrix_pasteCollapseRows(SEXP x, SEXP sep);
 
-void make_vcf_geno(SEXP conn, SEXP fixed, SEXP format, SEXP geno, 
-	               SEXP separators, SEXP vcf_dim, SEXP geno_zdim); 
+SEXP make_vcf_geno(SEXP conn, SEXP fixed, SEXP format, SEXP geno,
+		   SEXP separators, SEXP vcf_dim, SEXP geno_zdim);
 
 #endif
